==> qmapshack_1.3.0.orig.tar.gz: qmapshack-1.3.0/src/gis/trk/filter/CFilterObscureDate.cpp <==
/**********************************************************************************************
    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#include "gis/trk/CGisItemTrk.h"
#include "gis/trk/filter/CFilterObscureDate.h"
#include "helpers/CSettings.h"

CFilterObscureDate::CFilterObscureDate(CGisItemTrk &trk, QWidget *parent)
    : QWidget(parent)
    , trk(trk)
{
    setupUi(this);

    SETTINGS;
    spinBox->setValue(cfg.value("TrackDetails/Filter/ObscureTimestamp/delta",0).toInt());

    connect(toolApply, SIGNAL(clicked()), this, SLOT(slotApply()));
}

CFilterObscureDate::~CFilterObscureDate()
{
    SETTINGS;
    cfg.setValue("TrackDetails/Filter/ObscureTimestamp/delta", spinBox->value());
}

void CFilterObscureDate::slotApply()
{
    QApplication::setOverrideCursor(Qt::WaitCursor);
    trk.filterObscureDate(spinBox->value());
    QApplication::restoreOverrideCursor();
}

==> qmapshack_1.5.1.orig.tar.gz: qmapshack-1.5.1/src/gis/trk/filter/CFilterObscureDate.cpp <==
/**********************************************************************************************
    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#include "canvas/CCanvas.h"
#include "gis/trk/CGisItemTrk.h"
#include "gis/trk/filter/CFilterObscureDate.h"
#include "helpers/CSettings.h"

CFilterObscureDate::CFilterObscureDate(CGisItemTrk &trk, QWidget *parent)
    : QWidget(parent)
    , trk(trk)
{
    setupUi(this);

    SETTINGS;
    spinBox->setValue(cfg.value("TrackDetails/Filter/ObscureTimestamp/delta",0).toInt());

    connect(toolApply, SIGNAL(clicked()), this, SLOT(slotApply()));
}

CFilterObscureDate::~CFilterObscureDate()
{
    SETTINGS;
    cfg.setValue("TrackDetails/Filter/ObscureTimestamp/delta", spinBox->value());
}

void CFilterObscureDate::slotApply()
{
    CCanvas::setOverrideCursor(Qt::WaitCursor,"CFilterObscureDate");
    trk.filterObscureDate(spinBox->value());
    CCanvas::restoreOverrideCursor("CFilterObscureDate");
}
